/*========================================================================
 * IBM Confidential
 * OCO Source Materials
 *
 * IBM SDK, Java(tm) Technology Edition, v6
 * (C) Copyright IBM Corp. 1999, 2007. All Rights Reserved
 *
 * The source code for this program is not published or otherwise divested of
 * its trade secrets, irrespective of what has been deposited with the U.S.
 * Copyright office.
 *========================================================================
 */
/*
 * @(#)ListCellRenderer.java	1.19 05/11/17
 *
 * Copyright 2006 Sun Microsystems, Inc. All rights reserved.
 * SUN PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

package javax.swing;

import java.awt.Component;


/**
 * Identifies components that can be used as "rubber stamps" to paint
 * the cells in a JList.  For example, to use a JLabel as a
 * ListCellRenderer, you would write something like this:
 * <pre>
 * class MyCellRenderer extends JLabel implements ListCellRenderer {
 *     public MyCellRenderer() {
 *         setOpaque(true);
 *     }
 *
 *     public Component getListCellRendererComponent(JList list,
 *                                                   Object value,
 *                                                   int index,
 *                                                   boolean isSelected,
 *                                                   boolean cellHasFocus) {
 *
 *         setText(value.toString());
 *
 *         Color background;
 *         Color foreground;
 *
 *         // check if this cell represents the current DnD drop location
 *         JList.DropLocation dropLocation = list.getDropLocation();
 *         if (dropLocation != null
 *                 && !dropLocation.isInsert()
 *                 && dropLocation.getIndex() == index) {
 *
 *             background = Color.BLUE;
 *             foreground = Color.WHITE;
 *
 *         // check if this cell is selected
 *         } else if (isSelected) {
 *             background = Color.RED;
 *             foreground = Color.WHITE;
 *
 *         // unselected, and not the DnD drop location
 *         } else {
 *             background = Color.WHITE;
 *             foreground = Color.BLACK;
 *         };
 *
 *         setBackground(background);
 *         setForeground(foreground);
 *
 *         return this;
 *     }
 * }
 * </pre>
 *
 * @see JList
 * @see DefaultListCellRenderer
 *
 * @version 1.19 11/17/05
 * @author Hans Muller
 */
public interface ListCellRenderer
{
    /**
     * Return a component that has been configured to display the specified
     * value. That component's <code>paint</code> method is then called to
     * "render" the cell.  If it is necessary to compute the dimensions
     * of a list because the list cells do not have a fixed size, this method
     * is called to generate a component on which <code>getPreferredSize</code>
     * can be invoked.
     *
     * @param list The JList we're painting.
     * @param value The value returned by list.getModel().getElementAt(index).
     * @param index The cells index.
     * @param isSelected True if the specified cell was selected.
     * @param cellHasFocus True if the specified cell has the focus.
     * @return A component whose paint() method will render the specified value.
     *
     * @see JList
     * @see ListSelectionModel
     * @see ListModel
     */
    Component getListCellRendererComponent(
        JList list,
        Object value,
        int index,
        boolean isSelected,
        boolean cellHasFocus);
}
